<?php

namespace Drupal\search_api_coveo;

use Coveo\Search\SDK\SDKPushPHP\PushApiEndpoint;

/**
 * Client context class.
 */
class SeachApiClientContext {

  /**
   * The Coveo Field Batch path.
   */
  const FIELD_BATCH = '/indexes/fields/batch';

  /**
   * The Coveo Field page path.
   */
  const FIELD_PAGE = '/indexes/page/fields';

  /**
   * Organization Id.
   *
   * @var string
   */
  public $organizationID;

  /**
   * SourceID.
   *
   * @var string
   */
  public $sourceID;

  /**
   * ApiKey.
   *
   * @var string
   */

  public $apiKey;

  /**
   * Host URL.
   *
   * @var string
   */
  public $host;
  /**
   * Default Headers.
   *
   * @var array
   */
  public $defaultHeaders = [];

  /**
   * Field URL.
   *
   * @var string
   */
  public $fieldHost;


  /**
   * Organization Status URL.
   *
   * @var string
   */
  public $organizationHost;

  /**
   * Constructor.
   *
   * @param string|null $organizationID
   *   Organization (company) ID.
   * @param string|null $sourceID
   *   Push source ID.
   * @param string|null $apiKey
   *   Api key.
   * @param string $host
   *   Host.
   *
   * @throws \Exception
   */
  public function __construct($organizationID = NULL, $sourceID = NULL, $apiKey = NULL, $host = NULL) {
    $this->organizationID = $organizationID;
    $this->sourceID = $sourceID;
    $this->apiKey = $apiKey;

    if ($this->isEmpty($this->host)) {
      $this->host = PushApiEndpoint::HIPAA_PUSH_API_URL;
    }
    else {
      $this->host = $host;
    }

    $this->fieldHost = FieldsApiEndpoint::HIPAA_FIELDS_API_URL;

    if ($this->isEmpty($this->organizationID)) {
      throw new \Exception('CoveoSearch requires an organizationID.');
    }

    if ($this->isEmpty($this->sourceID)) {
      throw new \Exception('Coveo Search  requires an sourceID.');
    }
    // @todo add check for api key format
    if ($this->isEmpty($this->apiKey)) {
      throw new \Exception('Coveo Search requires an apiKey.');
    }

    $this->host = $this->host . '/organizations/' . $this->organizationID . '/sources/' . $this->sourceID . '/';

    $this->fieldHost = $this->fieldHost . '/organizations/' . $this->organizationID;

    $this->organizationHost = 'https://platformhipaa.cloud.coveo.com/rest/organizations/';

    $this->defaultHeaders = [
      'Accept' => 'application/json',
      'Content-Type' => 'application/json',
      'Authorization' => 'Bearer ' . $this->apiKey,
    ];
  }

  /**
   * Check if string is empty.
   *
   * @param string $s
   *   The string to check.
   *
   * @return bool
   *   Return true if $s string is empty or null.
   */
  private function isEmpty($s) {
    return ($s == NULL || mb_strlen($s) == 0);
  }

}
